==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/compute_region_url_map/ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite.java <==
package com.hashicorp.cdktf.providers.google.compute_region_url_map;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:39.946Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.computeRegionUrlMap.ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite")
@software.amazon.jsii.Jsii.Proxy(ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite extends software.amazon.jsii.JsiiSerializable {

    /**
     * Prior to forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.
     * <p>
     * The value must be between 1 and
     * 255 characters.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_region_url_map#host_rewrite ComputeRegionUrlMap#host_rewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHostRewrite() {
        return null;
    }

    /**
     * Prior to forwarding the request to the selected backend service, the matching portion of the request's path is replaced by pathPrefixRewrite.
     * <p>
     * The value must
     * be between 1 and 1024 characters.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_region_url_map#path_prefix_rewrite ComputeRegionUrlMap#path_prefix_rewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPathPrefixRewrite() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite> {
        java.lang.String hostRewrite;
        java.lang.String pathPrefixRewrite;

        /**
         * Sets the value of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite#getHostRewrite}
         * @param hostRewrite Prior to forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.
         *                    The value must be between 1 and
         *                    255 characters.
         *                    
         *                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_region_url_map#host_rewrite ComputeRegionUrlMap#host_rewrite}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hostRewrite(java.lang.String hostRewrite) {
            this.hostRewrite = hostRewrite;
            return this;
        }

        /**
         * Sets the value of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite#getPathPrefixRewrite}
         * @param pathPrefixRewrite Prior to forwarding the request to the selected backend service, the matching portion of the request's path is replaced by pathPrefixRewrite.
         *                          The value must
         *                          be between 1 and 1024 characters.
         *                          
         *                          Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_region_url_map#path_prefix_rewrite ComputeRegionUrlMap#path_prefix_rewrite}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder pathPrefixRewrite(java.lang.String pathPrefixRewrite) {
            this.pathPrefixRewrite = pathPrefixRewrite;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite {
        private final java.lang.String hostRewrite;
        private final java.lang.String pathPrefixRewrite;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.hostRewrite = software.amazon.jsii.Kernel.get(this, "hostRewrite", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.pathPrefixRewrite = software.amazon.jsii.Kernel.get(this, "pathPrefixRewrite", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.hostRewrite = builder.hostRewrite;
            this.pathPrefixRewrite = builder.pathPrefixRewrite;
        }

        @Override
        public final java.lang.String getHostRewrite() {
            return this.hostRewrite;
        }

        @Override
        public final java.lang.String getPathPrefixRewrite() {
            return this.pathPrefixRewrite;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getHostRewrite() != null) {
                data.set("hostRewrite", om.valueToTree(this.getHostRewrite()));
            }
            if (this.getPathPrefixRewrite() != null) {
                data.set("pathPrefixRewrite", om.valueToTree(this.getPathPrefixRewrite()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.computeRegionUrlMap.ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite.Jsii$Proxy that = (ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite.Jsii$Proxy) o;

            if (this.hostRewrite != null ? !this.hostRewrite.equals(that.hostRewrite) : that.hostRewrite != null) return false;
            return this.pathPrefixRewrite != null ? this.pathPrefixRewrite.equals(that.pathPrefixRewrite) : that.pathPrefixRewrite == null;
        }

        @Override
        public final int hashCode() {
            int result = this.hostRewrite != null ? this.hostRewrite.hashCode() : 0;
            result = 31 * result + (this.pathPrefixRewrite != null ? this.pathPrefixRewrite.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/compute_region_url_map/ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite.java <==
package com.hashicorp.cdktf.providers.google.compute_region_url_map;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:13.877Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.computeRegionUrlMap.ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite")
@software.amazon.jsii.Jsii.Proxy(ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite extends software.amazon.jsii.JsiiSerializable {

    /**
     * Prior to forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.
     * <p>
     * The value must be between 1 and
     * 255 characters.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_region_url_map#host_rewrite ComputeRegionUrlMap#host_rewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHostRewrite() {
        return null;
    }

    /**
     * Prior to forwarding the request to the selected backend service, the matching portion of the request's path is replaced by pathPrefixRewrite.
     * <p>
     * The value must
     * be between 1 and 1024 characters.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_region_url_map#path_prefix_rewrite ComputeRegionUrlMap#path_prefix_rewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPathPrefixRewrite() {
        return null;
    }

    /**
     * Prior to forwarding the request to the selected origin, if the request matched a pathTemplateMatch, the matching portion of the request's path is replaced re-written using the pattern specified by pathTemplateRewrite.
     * <p>
     * pathTemplateRewrite must be between 1 and 255 characters
     * (inclusive), must start with a '/', and must only use variables
     * captured by the route's pathTemplate matchers.
     * pathTemplateRewrite may only be used when all of a route's
     * MatchRules specify pathTemplate.
     * Only one of pathPrefixRewrite and pathTemplateRewrite may be
     * specified.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_region_url_map#path_template_rewrite ComputeRegionUrlMap#path_template_rewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPathTemplateRewrite() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite> {
        java.lang.String hostRewrite;
        java.lang.String pathPrefixRewrite;
        java.lang.String pathTemplateRewrite;

        /**
         * Sets the value of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite#getHostRewrite}
         * @param hostRewrite Prior to forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.
         *                    The value must be between 1 and
         *                    255 characters.
         *                    
         *                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_region_url_map#host_rewrite ComputeRegionUrlMap#host_rewrite}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hostRewrite(java.lang.String hostRewrite) {
            this.hostRewrite = hostRewrite;
            return this;
        }

        /**
         * Sets the value of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite#getPathPrefixRewrite}
         * @param pathPrefixRewrite Prior to forwarding the request to the selected backend service, the matching portion of the request's path is replaced by pathPrefixRewrite.
         *                          The value must
         *                          be between 1 and 1024 characters.
         *                          
         *                          Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_region_url_map#path_prefix_rewrite ComputeRegionUrlMap#path_prefix_rewrite}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder pathPrefixRewrite(java.lang.String pathPrefixRewrite) {
            this.pathPrefixRewrite = pathPrefixRewrite;
            return this;
        }

        /**
         * Sets the value of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite#getPathTemplateRewrite}
         * @param pathTemplateRewrite Prior to forwarding the request to the selected origin, if the request matched a pathTemplateMatch, the matching portion of the request's path is replaced re-written using the pattern specified by pathTemplateRewrite.
         *                            pathTemplateRewrite must be between 1 and 255 characters
         *                            (inclusive), must start with a '/', and must only use variables
         *                            captured by the route's pathTemplate matchers.
         *                            
         *                            pathTemplateRewrite may only be used when all of a route's
         *                            MatchRules specify pathTemplate.
         *                            
         *                            Only one of pathPrefixRewrite and pathTemplateRewrite may be
         *                            specified.
         *                            
         *                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_region_url_map#path_template_rewrite ComputeRegionUrlMap#path_template_rewrite}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder pathTemplateRewrite(java.lang.String pathTemplateRewrite) {
            this.pathTemplateRewrite = pathTemplateRewrite;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite {
        private final java.lang.String hostRewrite;
        private final java.lang.String pathPrefixRewrite;
        private final java.lang.String pathTemplateRewrite;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.hostRewrite = software.amazon.jsii.Kernel.get(this, "hostRewrite", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.pathPrefixRewrite = software.amazon.jsii.Kernel.get(this, "pathPrefixRewrite", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.pathTemplateRewrite = software.amazon.jsii.Kernel.get(this, "pathTemplateRewrite", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.hostRewrite = builder.hostRewrite;
            this.pathPrefixRewrite = builder.pathPrefixRewrite;
            this.pathTemplateRewrite = builder.pathTemplateRewrite;
        }

        @Override
        public final java.lang.String getHostRewrite() {
            return this.hostRewrite;
        }

        @Override
        public final java.lang.String getPathPrefixRewrite() {
            return this.pathPrefixRewrite;
        }

        @Override
        public final java.lang.String getPathTemplateRewrite() {
            return this.pathTemplateRewrite;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getHostRewrite() != null) {
                data.set("hostRewrite", om.valueToTree(this.getHostRewrite()));
            }
            if (this.getPathPrefixRewrite() != null) {
                data.set("pathPrefixRewrite", om.valueToTree(this.getPathPrefixRewrite()));
            }
            if (this.getPathTemplateRewrite() != null) {
                data.set("pathTemplateRewrite", om.valueToTree(this.getPathTemplateRewrite()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.computeRegionUrlMap.ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite.Jsii$Proxy that = (ComputeRegionUrlMapPathMatcherRouteRulesRouteActionUrlRewrite.Jsii$Proxy) o;

            if (this.hostRewrite != null ? !this.hostRewrite.equals(that.hostRewrite) : that.hostRewrite != null) return false;
            if (this.pathPrefixRewrite != null ? !this.pathPrefixRewrite.equals(that.pathPrefixRewrite) : that.pathPrefixRewrite != null) return false;
            return this.pathTemplateRewrite != null ? this.pathTemplateRewrite.equals(that.pathTemplateRewrite) : that.pathTemplateRewrite == null;
        }

        @Override
        public final int hashCode() {
            int result = this.hostRewrite != null ? this.hostRewrite.hashCode() : 0;
            result = 31 * result + (this.pathPrefixRewrite != null ? this.pathPrefixRewrite.hashCode() : 0);
            result = 31 * result + (this.pathTemplateRewrite != null ? this.pathTemplateRewrite.hashCode() : 0);
            return result;
        }
    }
}
